@@ -204,8 +204,6 @@ class Sale(Workflow, ModelSQL, ModelView, TaxableMixin):
                     'defined for the quotation of sale "%s".'),
                 'warehouse_required': ('Warehouse must be defined for the '
                     'quotation of sale "%s".'),
-                'missing_account_receivable': ('It misses '
-                        'an "Account Receivable" on the party "%s".'),
                 'delete_cancel': ('Sale "%s" must be cancelled before '
                     'deletion.'),
                 })
@@ -537,7 +535,8 @@ class Sale(Workflow, ModelSQL, ModelView, TaxableMixin):
 
     @classmethod
     def search_invoices(cls, name, clause):
-        return [('lines.invoice_lines.invoice',) + tuple(clause[1:])]
+        return [('lines.invoice_lines.invoice' + clause[0].lstrip(name),)
+            + tuple(clause[1:])]
 
     def get_invoice_state(self):
         '''
@@ -585,12 +584,17 @@ class Sale(Workflow, ModelSQL, ModelView, TaxableMixin):
         Search on shipments or returns
         '''
         def method(self, name, clause):
-            if isinstance(clause[2], basestring):
-                target = 'rec_name'
+            nested = clause[0].lstrip(name)
+            if nested:
+                return [('lines.moves.shipment' + nested,)
+                    + tuple(clause[1:3]) + (model_name,) + tuple(clause[3:])]
             else:
-                target = 'id'
-            return [('lines.moves.shipment.' + target,) + tuple(clause[1:])
-                + (model_name,)]
+                if isinstance(clause[2], basestring):
+                    target = 'rec_name'
+                else:
+                    target = 'id'
+                return [('lines.moves.shipment.' + target,)
+                    + tuple(clause[1:3]) + (model_name,)]
         return classmethod(method)
 
     search_shipments = search_shipments_returns('stock.shipment.out')
@@ -634,6 +638,13 @@ class Sale(Workflow, ModelSQL, ModelView, TaxableMixin):
                 ])
         return [(None, '')] + [(m.model, m.name) for m in models]
 
+    @property
+    def report_address(self):
+        if self.invoice_address:
+            return self.invoice_address.full_address
+        else:
+            return ''
+
     @classmethod
     def validate(cls, sales):
         super(Sale, cls).validate(sales)
@@ -747,7 +758,7 @@ class Sale(Workflow, ModelSQL, ModelView, TaxableMixin):
             party=self.party,
             invoice_address=self.invoice_address,
             currency=self.currency,
-            account=self.party.account_receivable,
+            account=self.party.account_receivable_used,
             )
         invoice.on_change_type()
         invoice.payment_term = self.payment_term
@@ -760,10 +771,6 @@ class Sale(Workflow, ModelSQL, ModelView, TaxableMixin):
         if self.invoice_method == 'manual':
             return
 
-        if not self.party.account_receivable:
-            self.raise_user_error('missing_account_receivable',
-                (self.party.rec_name,))
-
         invoice_lines = []
         for line in self.lines:
             invoice_lines.append(line.get_invoice_line())
@@ -911,6 +918,13 @@ class Sale(Workflow, ModelSQL, ModelView, TaxableMixin):
     def do(cls, sales):
         pass
 
+    @classmethod
+    def cron_process(cls):
+        sales = cls.search([
+                ('state', '=', 'confirmed'),
+                ])
+        cls.process(sales)
+
     @classmethod
     @ModelView.button
     def process(cls, sales):
@@ -1308,7 +1322,8 @@ class SaleLine(sequence_ordered(), ModelSQL, ModelView):
     def on_change_with_shipping_date(self, name=None):
         if self.moves:
             dates = filter(
-                None, (m.effective_date or m.planned_date for m in self.moves))
+                None, (m.effective_date or m.planned_date for m in self.moves
+                    if m.state != 'cancel'))
             if dates:
                 return min(dates)
             else:
@@ -1435,6 +1450,7 @@ class SaleLine(sequence_ordered(), ModelSQL, ModelView):
         '''
         pool = Pool()
         Move = pool.get('stock.move')
+        Date = pool.get('ir.date')
 
         if self.type != 'line':
             return
@@ -1468,7 +1484,11 @@ class SaleLine(sequence_ordered(), ModelSQL, ModelView):
         move.company = self.sale.company
         move.unit_price = self.unit_price
         move.currency = self.sale.currency
-        move.planned_date = self.shipping_date
+        if self.moves:
+            # backorder can not be planned
+            move.planned_date = Date.today()
+        else:
+            move.planned_date = self.shipping_date
         move.invoice_lines = self._get_move_invoice_lines(shipment_type)
         move.origin = self
         return move
